/**
 * @packageDocumentation
 * @module Array
 */
import { Observable, Subscribable } from 'rxjs';
/**
 * Returns an Observable that emits an Array from a Set
 *
 * @category Set
 *
 * @typeParam T The type of value contained in the Set
 *
 * @param input Input to create the emit values from, can be argument list of Set, an array of Set or an Observable
 *   or Promise source
 *
 * @example
 * Create Array from Set
 * ```ts
 * const input = new Set(1, 1, 2, 2, 3, 3, 4, 4);
 * fromSet(input).subscribe();
 * ```
 * Output: `[1, 2, 3, 4]`
 *
 * @returns Observable that emits an Array from the input Set
 */
export declare function fromSet<T extends unknown>(input: Subscribable<Iterable<Set<T>> | Set<T>> | Iterable<Set<T>> | Set<T>): Observable<T[]>;
